@@ -14,48 +14,36 @@ deviation ellipses, which can and will be derived very easily from
 the Quiver code.
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
-import six
+import math
 import weakref
 
 import numpy as np
 from numpy import ma
-import matplotlib.collections as mcollections
-import matplotlib.transforms as transforms
-import matplotlib.text as mtext
+
+from matplotlib import cbook, docstring, font_manager
 import matplotlib.artist as martist
-from matplotlib.artist import allow_rasterization
-from matplotlib import docstring
-import matplotlib.font_manager as font_manager
-import matplotlib.cbook as cbook
-from matplotlib.cbook import delete_masked_points
+import matplotlib.collections as mcollections
 from matplotlib.patches import CirclePolygon
-import math
+import matplotlib.text as mtext
+import matplotlib.transforms as transforms
 
 
 _quiver_doc = """
-Plot a 2-D field of arrows.
+Plot a 2D field of arrows.
 
-Call signatures::
+Call signature::
 
-  quiver(U, V, **kw)
-  quiver(U, V, C, **kw)
-  quiver(X, Y, U, V, **kw)
-  quiver(X, Y, U, V, C, **kw)
+  quiver([X, Y], U, V, [C], **kw)
 
-*U* and *V* are the arrow data, *X* and *Y* set the location of the
-arrows, and *C* sets the color of the arrows. These arguments may be 1-D or
-2-D arrays or sequences.
+Where *X*, *Y* define the arrow locations, *U*, *V* define the arrow
+directions, and *C* optionally sets the color.
 
-If *X* and *Y* are absent, they will be generated as a uniform grid.
-If *U* and *V* are 2-D arrays and *X* and *Y* are 1-D, and if ``len(X)`` and
-``len(Y)`` match the column and row dimensions of *U*, then *X* and *Y* will be
-expanded with :func:`numpy.meshgrid`.
+**Arrow size**
 
 The default settings auto-scales the length of the arrows to a reasonable size.
-To change this behavior see the *scale* and *scale_units* kwargs.
+To change this behavior see the *scale* and *scale_units* parameters.
+
+**Arrow shape**
 
 The defaults give a slightly swept-back arrow; to make the head a
 triangle, make *headaxislength* the same as *headlength*. To make the
@@ -64,31 +52,42 @@ arrow more pointed, reduce *headwidth* or increase *headlength* and
 scale down all the head parameters. You will probably do best to leave
 minshaft alone.
 
+**Arrow outline**
+
 *linewidths* and *edgecolors* can be used to customize the arrow
 outlines.
 
 Parameters
 ----------
-X : 1D or 2D array, sequence, optional
-    The x coordinates of the arrow locations
-Y : 1D or 2D array, sequence, optional
-    The y coordinates of the arrow locations
-U : 1D or 2D array or masked array, sequence
-    The x components of the arrow vectors
-V : 1D or 2D array or masked array, sequence
-    The y components of the arrow vectors
-C : 1D or 2D array, sequence, optional
-    The arrow colors
-units : [ 'width' | 'height' | 'dots' | 'inches' | 'x' | 'y' | 'xy' ]
+X, Y : 1D or 2D array-like, optional
+    The x and y coordinates of the arrow locations.
+
+    If not given, they will be generated as a uniform integer meshgrid based
+    on the dimensions of *U* and *V*.
+
+    If *X* and *Y* are 1D but *U*, *V* are 2D, *X*, *Y* are expanded to 2D
+    using ``X, Y = np.meshgrid(X, Y)``. In this case ``len(X)`` and ``len(Y)``
+    must match the column and row dimensions of *U* and *V*.
+
+U, V : 1D or 2D array-like
+    The x and y direction components of the arrow vectors.
+
+C : 1D or 2D array-like, optional
+    Numeric data that defines the arrow colors by colormapping via *norm* and
+    *cmap*.
+
+    This does not support explicit colors. If you want to set colors directly,
+    use *color* instead.
+
+units : {'width', 'height', 'dots', 'inches', 'x', 'y' 'xy'}, default: 'width'
     The arrow dimensions (except for *length*) are measured in multiples of
     this unit.
 
-    'width' or 'height': the width or height of the axis
+    The following values are supported:
 
-    'dots' or 'inches': pixels or inches, based on the figure dpi
-
-    'x', 'y', or 'xy': respectively *X*, *Y*, or :math:`\\sqrt{X^2 + Y^2}`
-    in data units
+    - 'width', 'height': The width or height of the axis.
+    - 'dots', 'inches': Pixels or inches based on the figure dpi.
+    - 'x', 'y', 'xy': *X*, *Y* or :math:`\\sqrt{X^2 + Y^2}` in data units.
 
     The arrows scale differently depending on the units.  For
     'x' or 'y', the arrows get larger as one zooms in; for other
@@ -96,78 +95,95 @@ units : [ 'width' | 'height' | 'dots' | 'inches' | 'x' | 'y' | 'xy' ]
     'width or 'height', the arrow size increases with the width and
     height of the axes, respectively, when the window is resized;
     for 'dots' or 'inches', resizing does not change the arrows.
-angles : [ 'uv' | 'xy' ], array, optional
-    Method for determining the angle of the arrows. Default is 'uv'.
 
-    'uv': the arrow axis aspect ratio is 1 so that
-    if *U*==*V* the orientation of the arrow on the plot is 45 degrees
-    counter-clockwise from the horizontal axis (positive to the right).
+angles : {'uv', 'xy'} or array-like, optional, default: 'uv'
+    Method for determining the angle of the arrows.
 
-    'xy': arrows point from (x,y) to (x+u, y+v).
-    Use this for plotting a gradient field, for example.
+    - 'uv': The arrow axis aspect ratio is 1 so that
+      if *U* == *V* the orientation of the arrow on the plot is 45 degrees
+      counter-clockwise from the horizontal axis (positive to the right).
 
-    Alternatively, arbitrary angles may be specified as an array
-    of values in degrees, counter-clockwise from the horizontal axis.
+      Use this if the arrows symbolize a quantity that is not based on
+      *X*, *Y* data coordinates.
+
+    - 'xy': Arrows point from (x,y) to (x+u, y+v).
+      Use this for plotting a gradient field, for example.
+
+    - Alternatively, arbitrary angles may be specified explicitly as an array
+      of values in degrees, counter-clockwise from the horizontal axis.
+
+      In this case *U*, *V* is only used to determine the length of the
+      arrows.
 
     Note: inverting a data axis will correspondingly invert the
     arrows only with ``angles='xy'``.
-scale : None, float, optional
+
+scale : float, optional
     Number of data units per arrow length unit, e.g., m/s per plot width; a
     smaller scale parameter makes the arrow longer. Default is *None*.
 
     If *None*, a simple autoscaling algorithm is used, based on the average
     vector length and the number of vectors. The arrow length unit is given by
-    the *scale_units* parameter
-scale_units : [ 'width' | 'height' | 'dots' | 'inches' | 'x' | 'y' | 'xy' ], \
-None, optional
+    the *scale_units* parameter.
+
+scale_units : {'width', 'height', 'dots', 'inches', 'x', 'y', 'xy'}, optional
     If the *scale* kwarg is *None*, the arrow length unit. Default is *None*.
 
     e.g. *scale_units* is 'inches', *scale* is 2.0, and
     ``(u,v) = (1,0)``, then the vector will be 0.5 inches long.
 
-    If *scale_units* is 'width'/'height', then the vector will be half the
+    If *scale_units* is 'width' or 'height', then the vector will be half the
     width/height of the axes.
 
     If *scale_units* is 'x' then the vector will be 0.5 x-axis
     units. To plot vectors in the x-y plane, with u and v having
     the same units as x and y, use
     ``angles='xy', scale_units='xy', scale=1``.
-width : scalar, optional
+
+width : float, optional
     Shaft width in arrow units; default depends on choice of units,
     above, and number of vectors; a typical starting value is about
     0.005 times the width of the plot.
-headwidth : scalar, optional
-    Head width as multiple of shaft width, default is 3
-headlength : scalar, optional
-    Head length as multiple of shaft width, default is 5
-headaxislength : scalar, optional
-    Head length at shaft intersection, default is 4.5
-minshaft : scalar, optional
+
+headwidth : float, optional, default: 3
+    Head width as multiple of shaft width.
+
+headlength : float, optional, default: 5
+    Head length as multiple of shaft width.
+
+headaxislength : float, optional, default: 4.5
+    Head length at shaft intersection.
+
+minshaft : float, optional, default: 1
     Length below which arrow scales, in units of head length. Do not
     set this to less than 1, or small arrows will look terrible!
-    Default is 1
-minlength : scalar, optional
+
+minlength : float, optional, default: 1
     Minimum length as a multiple of shaft width; if an arrow length
     is less than this, plot a dot (hexagon) of this diameter instead.
-    Default is 1.
-pivot : [ 'tail' | 'mid' | 'middle' | 'tip' ], optional
-    The part of the arrow that is at the grid point; the arrow rotates
-    about this point, hence the name *pivot*.
-color : [ color | color sequence ], optional
-    This is a synonym for the
-    :class:`~matplotlib.collections.PolyCollection` facecolor kwarg.
-    If *C* has been set, *color* has no effect.
 
-Notes
------
-Additional :class:`~matplotlib.collections.PolyCollection`
-keyword arguments:
+pivot : {'tail', 'mid', 'middle', 'tip'}, optional, default: 'tail'
+    The part of the arrow that is anchored to the *X*, *Y* grid. The arrow
+    rotates about this point.
 
-%(PolyCollection)s
+    'mid' is a synonym for 'middle'.
+
+color : color or color sequence, optional
+    Explicit color(s) for the arrows. If *C* has been set, *color* has no
+    effect.
+
+    This is a synonym for the `~.PolyCollection` *facecolor* parameter.
+
+Other Parameters
+----------------
+**kwargs : `~matplotlib.collections.PolyCollection` properties, optional
+    All other keyword arguments are passed on to `.PolyCollection`:
+
+    %(PolyCollection)s
 
 See Also
 --------
-quiverkey : Add a key to a quiver plot
+quiverkey : Add a key to a quiver plot.
 """ % docstring.interpd.params
 
 _quiverkey_doc = """
@@ -242,17 +258,20 @@ class QuiverKey(martist.Artist):
     valign = {'N': 'bottom', 'S': 'top', 'E': 'center', 'W': 'center'}
     pivot = {'N': 'middle', 'S': 'middle', 'E': 'tip', 'W': 'tail'}
 
-    def __init__(self, Q, X, Y, U, label, **kw):
+    def __init__(self, Q, X, Y, U, label,
+                 *, angle=0, coordinates='axes', color=None, labelsep=0.1,
+                 labelpos='N', labelcolor=None, fontproperties=None,
+                 **kw):
         martist.Artist.__init__(self)
         self.Q = Q
         self.X = X
         self.Y = Y
         self.U = U
-        self.angle = kw.pop('angle', 0)
-        self.coord = kw.pop('coordinates', 'axes')
-        self.color = kw.pop('color', None)
+        self.angle = angle
+        self.coord = coordinates
+        self.color = color
         self.label = label
-        self._labelsep_inches = kw.pop('labelsep', 0.1)
+        self._labelsep_inches = labelsep
         self.labelsep = (self._labelsep_inches * Q.ax.figure.dpi)
 
         # try to prevent closure over the real self
@@ -270,9 +289,9 @@ class QuiverKey(martist.Artist):
         self._cid = Q.ax.figure.callbacks.connect('dpi_changed',
                                                   on_dpi_change)
 
-        self.labelpos = kw.pop('labelpos', 'N')
-        self.labelcolor = kw.pop('labelcolor', None)
-        self.fontproperties = kw.pop('fontproperties', dict())
+        self.labelpos = labelpos
+        self.labelcolor = labelcolor
+        self.fontproperties = fontproperties or dict()
         self.kw = kw
         _fp = self.fontproperties
         # boxprops = dict(facecolor='red')
@@ -308,9 +327,11 @@ class QuiverKey(martist.Artist):
             # Hack: save and restore the Umask
             _mask = self.Q.Umask
             self.Q.Umask = ma.nomask
-            self.verts = self.Q._make_verts(np.array([self.U]),
-                                            np.zeros((1,)),
-                                            self.angle)
+            u = self.U * np.cos(np.radians(self.angle))
+            v = self.U * np.sin(np.radians(self.angle))
+            angle = self.Q.angles if isinstance(self.Q.angles, str) else 'uv'
+            self.verts = self.Q._make_verts(
+                np.array([u]), np.array([v]), angle)
             self.Q.Umask = _mask
             self.Q.pivot = _pivot
             kw = self.Q.polykw
@@ -342,7 +363,7 @@ class QuiverKey(martist.Artist):
         else:
             return y
 
-    @allow_rasterization
+    @martist.allow_rasterization
     def draw(self, renderer):
         self._init()
         self.vector.draw(renderer)
@@ -383,7 +404,7 @@ class QuiverKey(martist.Artist):
 # arguments for doing colored vector plots.  Pulling it out here
 # allows both Quiver and Barbs to use it
 def _parse_args(*args):
-    X, Y, U, V, C = [None] * 5
+    X = Y = U = V = C = None
     args = list(args)
 
     # The use of atleast_1d allows for handling scalar arguments while also
@@ -392,6 +413,7 @@ def _parse_args(*args):
         C = np.atleast_1d(args.pop(-1))
     V = np.atleast_1d(args.pop(-1))
     U = np.atleast_1d(args.pop(-1))
+    cbook._check_not_matrix(U=U, V=V, C=C)
     if U.ndim == 1:
         nr, nc = 1, U.shape[0]
     else:
@@ -407,9 +429,9 @@ def _parse_args(*args):
 
 
 def _check_consistent_shapes(*arrays):
-    all_shapes = set(a.shape for a in arrays)
+    all_shapes = {a.shape for a in arrays}
     if len(all_shapes) != 1:
-        raise ValueError('The shapes of the passed in arrays do not match.')
+        raise ValueError('The shapes of the passed in arrays do not match')
 
 
 class Quiver(mcollections.PolyCollection):
@@ -430,47 +452,43 @@ class Quiver(mcollections.PolyCollection):
     in the draw() method.
     """
 
-    _PIVOT_VALS = ('tail', 'mid', 'middle', 'tip')
+    _PIVOT_VALS = ('tail', 'middle', 'tip')
 
     @docstring.Substitution(_quiver_doc)
-    def __init__(self, ax, *args, **kw):
+    def __init__(self, ax, *args,
+                 scale=None, headwidth=3, headlength=5, headaxislength=4.5,
+                 minshaft=1, minlength=1, units='width', scale_units=None,
+                 angles='uv', width=None, color='k', pivot='tail', **kw):
         """
         The constructor takes one required argument, an Axes
         instance, followed by the args and kwargs described
-        by the following pylab interface documentation:
+        by the following pyplot interface documentation:
         %s
         """
         self.ax = ax
         X, Y, U, V, C = _parse_args(*args)
         self.X = X
         self.Y = Y
-        self.XY = np.hstack((X[:, np.newaxis], Y[:, np.newaxis]))
+        self.XY = np.column_stack((X, Y))
         self.N = len(X)
-        self.scale = kw.pop('scale', None)
-        self.headwidth = kw.pop('headwidth', 3)
-        self.headlength = float(kw.pop('headlength', 5))
-        self.headaxislength = kw.pop('headaxislength', 4.5)
-        self.minshaft = kw.pop('minshaft', 1)
-        self.minlength = kw.pop('minlength', 1)
-        self.units = kw.pop('units', 'width')
-        self.scale_units = kw.pop('scale_units', None)
-        self.angles = kw.pop('angles', 'uv')
-        self.width = kw.pop('width', None)
-        self.color = kw.pop('color', 'k')
+        self.scale = scale
+        self.headwidth = headwidth
+        self.headlength = float(headlength)
+        self.headaxislength = headaxislength
+        self.minshaft = minshaft
+        self.minlength = minlength
+        self.units = units
+        self.scale_units = scale_units
+        self.angles = angles
+        self.width = width
 
-        pivot = kw.pop('pivot', 'tail').lower()
-        # validate pivot
-        if pivot not in self._PIVOT_VALS:
-            raise ValueError(
-                'pivot must be one of {keys}, you passed {inp}'.format(
-                      keys=self._PIVOT_VALS, inp=pivot))
-        # normalize to 'middle'
-        if pivot == 'mid':
+        if pivot.lower() == 'mid':
             pivot = 'middle'
-        self.pivot = pivot
+        self.pivot = pivot.lower()
+        cbook._check_in_list(self._PIVOT_VALS, pivot=self.pivot)
 
         self.transform = kw.pop('transform', ax.transData)
-        kw.setdefault('facecolors', self.color)
+        kw.setdefault('facecolors', color)
         kw.setdefault('linewidths', (0,))
         mcollections.PolyCollection.__init__(self, [], offsets=self.XY,
                                              transOffset=self.transform,
@@ -480,9 +498,6 @@ class Quiver(mcollections.PolyCollection):
         self.set_UVC(U, V, C)
         self._initialized = False
 
-        self.keyvec = None
-        self.keytext = None
-
         # try to prevent closure over the real self
         weak_self = weakref.ref(self)
 
@@ -499,6 +514,21 @@ class Quiver(mcollections.PolyCollection):
         self._cid = self.ax.figure.callbacks.connect('dpi_changed',
                                                      on_dpi_change)
 
+    @cbook.deprecated("3.1", alternative="get_facecolor()")
+    @property
+    def color(self):
+        return self.get_facecolor()
+
+    @cbook.deprecated("3.1")
+    @property
+    def keyvec(self):
+        return None
+
+    @cbook.deprecated("3.1")
+    @property
+    def keytext(self):
+        return None
+
     def remove(self):
         """
         Overload the remove method
@@ -541,7 +571,7 @@ class Quiver(mcollections.PolyCollection):
         bbox.update_from_data_xy(XY, ignore=True)
         return bbox
 
-    @allow_rasterization
+    @martist.allow_rasterization
     def draw(self, renderer):
         self._init()
         verts = self._make_verts(self.U, self.V, self.angles)
@@ -617,7 +647,7 @@ class Quiver(mcollections.PolyCollection):
 
     def _angles_lengths(self, U, V, eps=1):
         xy = self.ax.transData.transform(self.XY)
-        uv = np.hstack((U[:, np.newaxis], V[:, np.newaxis]))
+        uv = np.column_stack((U, V))
         xyp = self.ax.transData.transform(self.XY + eps * uv)
         dxy = xyp - xy
         angles = np.arctan2(dxy[:, 1], dxy[:, 0])
@@ -626,7 +656,7 @@ class Quiver(mcollections.PolyCollection):
 
     def _make_verts(self, U, V, angles):
         uv = (U + V * 1j)
-        str_angles = angles if isinstance(angles, six.string_types) else ''
+        str_angles = angles if isinstance(angles, str) else ''
         if str_angles == 'xy' and self.scale_units == 'xy':
             # Here eps is 1 so that if we get U, V by diffing
             # the X, Y arrays, the vectors will connect the
@@ -673,8 +703,7 @@ class Quiver(mcollections.PolyCollection):
             theta = ma.masked_invalid(np.deg2rad(angles)).filled(0)
         theta = theta.reshape((-1, 1))  # for broadcasting
         xy = (X + Y * 1j) * np.exp(1j * theta) * self.width
-        xy = xy[:, :, np.newaxis]
-        XY = np.concatenate((xy.real, xy.imag), axis=2)
+        XY = np.stack((xy.real, xy.imag), axis=2)
         if self.Umask is not ma.nomask:
             XY = ma.array(XY)
             XY[self.Umask] = ma.masked
@@ -707,11 +736,11 @@ class Quiver(mcollections.PolyCollection):
                        minsh - self.headlength, minsh], np.float64)
         y0 = 0.5 * np.array([1, 1, self.headwidth, 0], np.float64)
         ii = [0, 1, 2, 3, 2, 1, 0, 0]
-        X = x.take(ii, 1)
-        Y = y.take(ii, 1)
+        X = x[:, ii]
+        Y = y[:, ii]
         Y[:, 3:-1] *= -1
-        X0 = x0.take(ii)
-        Y0 = y0.take(ii)
+        X0 = x0[ii]
+        Y0 = y0[ii]
         Y0[3:-1] *= -1
         shrink = length / minsh if minsh != 0. else 0.
         X0 = shrink * X0[np.newaxis, :]
@@ -793,13 +822,13 @@ Keyword arguments:
 
   *barbcolor*: [ color | color sequence ]
     Specifies the color all parts of the barb except any flags.  This
-    parameter is analagous to the *edgecolor* parameter for polygons,
+    parameter is analogous to the *edgecolor* parameter for polygons,
     which can be used instead. However this parameter will override
     facecolor.
 
   *flagcolor*: [ color | color sequence ]
     Specifies the color of any flags on the barb.  This parameter is
-    analagous to the *facecolor* parameter for polygons, which can be
+    analogous to the *facecolor* parameter for polygons, which can be
     used instead. However this parameter will override facecolor.  If
     this is not set (and *C* has not either) then *flagcolor* will be
     set to match *barbcolor* so that the barb has a uniform color. If
@@ -907,23 +936,26 @@ class Barbs(mcollections.PolyCollection):
     # 1 triangle and a series of lines.  It works fine as far as I can tell
     # however.
     @docstring.interpd
-    def __init__(self, ax, *args, **kw):
+    def __init__(self, ax, *args,
+                 pivot='tip', length=7, barbcolor=None, flagcolor=None,
+                 sizes=None, fill_empty=False, barb_increments=None,
+                 rounding=True, flip_barb=False, **kw):
         """
         The constructor takes one required argument, an Axes
         instance, followed by the args and kwargs described
-        by the following pylab interface documentation:
+        by the following pyplot interface documentation:
         %(barbs_doc)s
         """
-        self._pivot = kw.pop('pivot', 'tip')
-        self._length = kw.pop('length', 7)
-        barbcolor = kw.pop('barbcolor', None)
-        flagcolor = kw.pop('flagcolor', None)
-        self.sizes = kw.pop('sizes', dict())
-        self.fill_empty = kw.pop('fill_empty', False)
-        self.barb_increments = kw.pop('barb_increments', dict())
-        self.rounding = kw.pop('rounding', True)
-        self.flip = kw.pop('flip_barb', False)
+        self.sizes = sizes or dict()
+        self.fill_empty = fill_empty
+        self.barb_increments = barb_increments or dict()
+        self.rounding = rounding
+        self.flip = flip_barb
         transform = kw.pop('transform', ax.transData)
+        self._pivot = pivot
+        self._length = length
+        barbcolor = barbcolor
+        flagcolor = flagcolor
 
         # Flagcolor and barbcolor provide convenience parameters for
         # setting the facecolor and edgecolor, respectively, of the barb
@@ -952,7 +984,7 @@ class Barbs(mcollections.PolyCollection):
         x, y, u, v, c = _parse_args(*args)
         self.x = x
         self.y = y
-        xy = np.hstack((x[:, np.newaxis], y[:, np.newaxis]))
+        xy = np.column_stack((x, y))
 
         # Make a collection
         barb_size = self._length ** 2 / 4  # Empirically determined
@@ -985,10 +1017,10 @@ class Barbs(mcollections.PolyCollection):
             mag = half * (mag / half + 0.5).astype(int)
 
         num_flags = np.floor(mag / flag).astype(int)
-        mag = np.mod(mag, flag)
+        mag = mag % flag
 
         num_barb = np.floor(mag / full).astype(int)
-        mag = np.mod(mag, full)
+        mag = mag % full
 
         half_flag = mag >= half
         empty_flag = ~(half_flag | (num_flags > 0) | (num_barb > 0))
@@ -1145,13 +1177,12 @@ class Barbs(mcollections.PolyCollection):
         self.v = ma.masked_invalid(V, copy=False).ravel()
         if C is not None:
             c = ma.masked_invalid(C, copy=False).ravel()
-            x, y, u, v, c = delete_masked_points(self.x.ravel(),
-                                                 self.y.ravel(),
-                                                 self.u, self.v, c)
+            x, y, u, v, c = cbook.delete_masked_points(
+                self.x.ravel(), self.y.ravel(), self.u, self.v, c)
             _check_consistent_shapes(x, y, u, v, c)
         else:
-            x, y, u, v = delete_masked_points(self.x.ravel(), self.y.ravel(),
-                                              self.u, self.v)
+            x, y, u, v = cbook.delete_masked_points(
+                self.x.ravel(), self.y.ravel(), self.u, self.v)
             _check_consistent_shapes(x, y, u, v)
 
         magnitude = np.hypot(u, v)
@@ -1171,27 +1202,26 @@ class Barbs(mcollections.PolyCollection):
             self.set_array(c)
 
         # Update the offsets in case the masked data changed
-        xy = np.hstack((x[:, np.newaxis], y[:, np.newaxis]))
+        xy = np.column_stack((x, y))
         self._offsets = xy
         self.stale = True
 
     def set_offsets(self, xy):
         """
         Set the offsets for the barb polygons.  This saves the offsets passed
-        in and actually sets version masked as appropriate for the existing
-        U/V data. *offsets* should be a sequence.
+        in and masks them as appropriate for the existing U/V data.
 
-        ACCEPTS: sequence of pairs of floats
+        Parameters
+        ----------
+        xy : sequence of pairs of floats
         """
         self.x = xy[:, 0]
         self.y = xy[:, 1]
-        x, y, u, v = delete_masked_points(self.x.ravel(), self.y.ravel(),
-                                          self.u, self.v)
+        x, y, u, v = cbook.delete_masked_points(
+            self.x.ravel(), self.y.ravel(), self.u, self.v)
         _check_consistent_shapes(x, y, u, v)
-        xy = np.hstack((x[:, np.newaxis], y[:, np.newaxis]))
+        xy = np.column_stack((x, y))
         mcollections.PolyCollection.set_offsets(self, xy)
         self.stale = True
 
-    set_offsets.__doc__ = mcollections.PolyCollection.set_offsets.__doc__
-
     barbs_doc = _barbs_doc
